@@ -553,7 +553,7 @@ def _process_model_selection(  # pylint: disable=too-many-locals,inconsistent-re
         gpu_index=args["gpu_index"],
         plot=args["plot"],
     )
-    model = model_selection.fit(graph, symmetric=args["symmetric"])
+    model = model_selection.fit(graph, symmetric=args["symmetric"]).best
 
     if not model.trained_successfully:
         logger.error("FAILED, model has not been trained successfully.")
