@@ -188,7 +188,9 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
         """bool: Returns the predicted column classes membership probabilities"""
         return self.trained_successfully_
 
-    def get_params(self, _=True):  # pylint: disable=missing-function-docstring
+    def get_params(
+        self, deep=True
+    ):  # pylint: disable=missing-function-docstring,unused-argument
         return {
             "max_iter": self.max_iter,
             "n_init": self.n_init,
@@ -264,7 +266,7 @@ class LBM(BaseEstimator):  # pylint: disable=too-many-instance-attributes
             * np.log(self._nb_cols * self._nb_rows)
         )
 
-    def fit(  # pylint: disable=too-many-locals,too-many-branches,invalid-name,missing-type-doc
+    def fit(  # pylint: disable=too-many-locals,too-many-branches,invalid-name,missing-type-doc,unused-argument
         self, X, _=None
     ) -> None:
         """Perform co-clustering by direct maximization of graph modularity.
