@@ -32,13 +32,14 @@ import scipy.sparse as sp
 import matplotlib.pyplot as plt
 from scipy.sparse import spmatrix
 
-from . import SBM, LBM
-from .utils import (
+from sparsebm import SBM, LBM
+from sparsebm.utils import (
     lbm_merge_group,
     sbm_merge_group,
     lbm_split_group,
     sbm_split_group,
 )
+from sparsebm._datatypes import ModelSelectionResults
 
 logger = logging.getLogger(__name__)
 
@@ -63,11 +64,26 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
 
     Examples
     --------
-    >>> lbm_model_selection = ModelSelection(
-    ...     model_type="LBM",
-    ...     plot=True,
+    For SBM model selection:
+
+    >>> sbm_model_selection = ModelSelection(
+    ... model_type="SBM",
+    ... plot=True,
     ... )
-    >>> lbm_selected = lbm_model_selection.fit(graph)
+    >>> sbm_selection = sbm_model_selection.fit(graph)
+    >>> sbm_selection.best # to access the best (ICL) fitted model
+    >>> sbm_selection[4] # to access the fitted model for 4 groups
+
+    For LBM model selection:
+
+    >>> lbm_model_selection = ModelSelection(
+    ... model_type="LBM",
+    ... plot=True,
+    ... )
+    >>> lbm_selection = lbm_model_selection.fit(graph)
+    >>> lbm_selection.best # to access the best (ICL) fitted model
+    >>> lbm_selection[4,3] # to access the fitted model
+    ...                    # for 4 row-group and 3 col-group
     """
 
     def __init__(
@@ -121,12 +137,27 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
             key=lambda x: x.get_ICL(),
         )
 
+    @property
+    def selection_result(self) -> ModelSelectionResults:
+        """ModelSelectionResults : Return a object representing explored models"""
+        assert self.model_explored, "Model selection not trained. Use fit()"
+        return ModelSelectionResults(
+            {
+                (
+                    model.n_row_clusters + model.n_column_clusters
+                    if self._model_type == "LBM"
+                    else model.n_clusters
+                ): model
+                for model in self.model_explored.values()
+            }
+        )
+
     def fit(
         # pylint: disable=unsubscriptable-object
         self,
         graph: Union[spmatrix, np.ndarray],
         symmetric: Optional[bool] = False,
-    ) -> Union[LBM, SBM]:
+    ) -> ModelSelectionResults:
         # pylint: disable=line-too-long
         """Perform model selection of the co-clustering.
 
@@ -139,8 +170,8 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
 
         Returns
         -------
-        sparsebm.LBM or sparsebm.SBM
-            The best trained model according to the ICL.
+        ModelSelectionResults
+           A object storing best model (according to ICL) and all trained models.
 
         Raises
         ------
@@ -232,7 +263,7 @@ class ModelSelection:  # pylint: disable=too-many-instance-attributes
         if self._plot:
             figure, _ = self._figure
             plt.close(figure)
-        return self.selected_model
+        return self.selection_result
 
     def __repr__(self) -> str:
         return f"""ModelSelection(
